======================================
 wphelper --- WordPress Author Helper
======================================

Tools for working with WordPress as a blog author.

Credits
=======

Some of the ideas in wphelper are based on
https://github.com/alonisser/PushToWordpress

* Free software: Apache license
* Source: http://github.com/dhellmann/wphelper
